"use client";
import {
	DropdownMenu,
	DropdownMenuContent,
	DropdownMenuItem,
	DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu";
import { Link } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { useBasicInfo } from "@/servers/data/use-basicinfo";
import { headerData } from "@/utils/get-fake-data";
import Cookies from "js-cookie";
import { ChevronDown } from "lucide-react";
import { usePathname } from "next/navigation";
import React from "react";
import { HeaderProps } from "./header-2";


export default function Navigation2({ locale }: HeaderProps) {
	const { menuItems } = headerData.navigation;
	const pathname = usePathname();
	const { texts } = useBasicInfo();

	const [status, setStatus] = React.useState(true);

	React.useEffect(() => {
		const __success = Cookies.get("__t") !== undefined;
		setStatus(__success);
	}, []);

	const isActive = (href: string) => {
		if (href === "/") {
			return pathname === `/${locale}`;
		}
		return pathname === `/${locale}${href}`;
	};

	const isVisible = (label: string) => {
		if (label === "Our Products" && texts?.show_our_products_section !== "on") return false;
		else if (label === "Our Services" && texts?.show_our_services_section !== "on") return false;
		else if (label === "Request a visit" && texts?.show_simulation_program_section !== "on") return false;

		return true;
	};

	return (
		<nav className="hidden text-[#606676] lg:block">
			<ul className="flex items-center gap-8">
				{menuItems?.map((item) => (
					isVisible(item.label?.["en"]) &&
					<li key={item.href} className="relative">
						<>
							{item.hasDropdown ? (
								<DropdownMenu>
									<DropdownMenuTrigger className="flex items-center gap-1 hover:text-custom-tertiary">
										{item.label?.[locale]}
										<ChevronDown className="size-4" />
									</DropdownMenuTrigger>
									<DropdownMenuContent align="end" className="w-48">
										{item.dropdownItems?.map((dropdownItem) => (
											<DropdownMenuItem key={dropdownItem.id}>
												<Link href={item.href as any} className="w-full">
													{dropdownItem.label?.[locale]}
												</Link>
											</DropdownMenuItem>
										))}
									</DropdownMenuContent>
								</DropdownMenu>
							) : (
								<Link
									href={(item.href === "/simulation-program" && !status) ? "/login" as any : (item.href as any)}
									className={cn(
										"relative py-2 hover:text-custom-dark",
										isActive(item.href) && "font-bold"
									)}
								>
									{item.label?.[locale]}
									{isActive(item.href) && (
										<span className="absolute bottom-0 left-1/2 mt-1 size-1.5 -translate-x-1/2 rounded-full bg-[#606676]" />
									)}
								</Link>
							)}
						</>
					</li>
				))}
			</ul>
		</nav>
	);
}
